---
name: "\U0001F41B Bug Report"
about: Something isn't working as expected

---

## Bug Report

**What version of Tonbo are you using?**


**What version of Rust are you using?**


**What's the status of the running?**

**What did you do?**
<!-- If possible, provide a recipe for reproducing the error. How you start Tonbo. -->

**What did you expect to see?**

**What did you see instead?**
